==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Dropdown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DropdownPlacement_$type } from "./DropdownPlacement";
import { DropdownPositionStrategy_$type } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy_$type } from "./DropdownScrollStrategy";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { DropdownItemComponentEventArgs } from "./DropdownItemComponentEventArgs";
/**
 * @hidden
 */
export let Dropdown = /*@__PURE__*/ (() => {
    class Dropdown extends BaseElement {
        constructor() {
            super(...arguments);
            this.h = new WCNativeHelper();
            this.p = null;
            this.change = null;
        }
        v() {
            this.nativeElement.show();
        }
        x() {
            this.nativeElement.toggle();
        }
        showTarget(target_) {
            this.nativeElement.show(target_);
        }
        toggleTarget(target_) {
            this.nativeElement.toggle(target_);
        }
        a(a) {
            return (this.nativeElement.navigateTo(a));
        }
        b(a) {
            return (this.nativeElement.select(a));
        }
        get i() {
            return this.h;
        }
        get nativeElement() {
            return this.p;
        }
        set nativeElement(a) {
            this.p = a;
            this.h.d = this.p;
        }
        get l() {
            let ret_ = this.i.c("keepOpenOnSelect");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.i.i("keepOpenOnSelect", value_);
        }
        get m() {
            let ret_ = this.i.c("open");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.i.i("open", value_);
        }
        get d() {
            let ret_ = this.i.c("placement");
            ret_ = enumGetBox(DropdownPlacement_$type, EnumUtil.getEnumValue(DropdownPlacement_$type, EnumUtil.parse(DropdownPlacement_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(DropdownPlacement_$type, ret_);
        }
        set d(a) {
            let value_ = enumGetBox(DropdownPlacement_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.i.i("placement", value_);
        }
        get e() {
            let ret_ = this.i.c("positionStrategy");
            ret_ = enumGetBox(DropdownPositionStrategy_$type, EnumUtil.getEnumValue(DropdownPositionStrategy_$type, EnumUtil.parse(DropdownPositionStrategy_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(DropdownPositionStrategy_$type, ret_);
        }
        set e(a) {
            let value_ = enumGetBox(DropdownPositionStrategy_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.i.i("positionStrategy", value_);
        }
        get f() {
            let ret_ = this.i.c("scrollStrategy");
            ret_ = enumGetBox(DropdownScrollStrategy_$type, EnumUtil.getEnumValue(DropdownScrollStrategy_$type, EnumUtil.parse(DropdownScrollStrategy_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(DropdownScrollStrategy_$type, ret_);
        }
        set f(a) {
            let value_ = enumGetBox(DropdownScrollStrategy_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.i.i("scrollStrategy", value_);
        }
        get j() {
            let ret_ = this.i.c("flip");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.i.i("flip", value_);
        }
        get o() {
            let ret_ = this.i.c("distance");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.i.i("distance", value_);
        }
        get k() {
            let ret_ = this.i.c("keepOpenOnOutsideClick");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.i.i("keepOpenOnOutsideClick", value_);
        }
        get n() {
            let ret_ = this.i.c("sameWidth");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.i.i("sameWidth", value_);
        }
        get g() {
            let ret_ = this.i.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set g(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.i.i("size", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.i.g("change", (a) => this.change(this, DropdownItemComponentEventArgs.b(a)));
            }
            else {
                this.i.h("change");
            }
        }
        t() {
            this.nativeElement.firstUpdated();
        }
        u() {
            this.nativeElement.hide();
        }
        s() {
            this.nativeElement.clearSelection();
        }
    }
    Dropdown.$t = /*@__PURE__*/ markType(Dropdown, 'Dropdown', BaseElement.$);
    return Dropdown;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Dropdown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DropdownPlacement_$type } from "./DropdownPlacement";
import { DropdownPositionStrategy_$type } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy_$type } from "./DropdownScrollStrategy";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { DropdownItemComponentEventArgs } from "./DropdownItemComponentEventArgs";
/**
 * @hidden
 */
export let Dropdown = /*@__PURE__*/ (() => {
    class Dropdown extends BaseElement {
        constructor() {
            super(...arguments);
            this.h = new WCNativeHelper();
            this.p = null;
            this.change = null;
        }
        v() {
            this.nativeElement.show();
        }
        x() {
            this.nativeElement.toggle();
        }
        showTarget(target_) {
            this.nativeElement.show(target_);
        }
        toggleTarget(target_) {
            this.nativeElement.toggle(target_);
        }
        a(a) {
            return (this.nativeElement.navigateTo(a));
        }
        b(a) {
            return (this.nativeElement.select(a));
        }
        get i() {
            return this.h;
        }
        get nativeElement() {
            return this.p;
        }
        set nativeElement(a) {
            this.p = a;
            this.h.o = this.p;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get l() {
            let ret_ = this.i.n("keepOpenOnSelect");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.i.v("keepOpenOnSelect", value_);
        }
        get m() {
            let ret_ = this.i.n("open");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.i.v("open", value_);
        }
        get d() {
            let ret_ = this.i.n("placement");
            ret_ = enumGetBox(DropdownPlacement_$type, EnumUtil.getEnumValue(DropdownPlacement_$type, this.i.f(DropdownPlacement_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownPlacement_$type, ret_);
        }
        set d(a) {
            let value_ = enumGetBox(DropdownPlacement_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("placement", value_);
        }
        get e() {
            let ret_ = this.i.n("positionStrategy");
            ret_ = enumGetBox(DropdownPositionStrategy_$type, EnumUtil.getEnumValue(DropdownPositionStrategy_$type, this.i.f(DropdownPositionStrategy_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownPositionStrategy_$type, ret_);
        }
        set e(a) {
            let value_ = enumGetBox(DropdownPositionStrategy_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("positionStrategy", value_);
        }
        get f() {
            let ret_ = this.i.n("scrollStrategy");
            ret_ = enumGetBox(DropdownScrollStrategy_$type, EnumUtil.getEnumValue(DropdownScrollStrategy_$type, this.i.f(DropdownScrollStrategy_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownScrollStrategy_$type, ret_);
        }
        set f(a) {
            let value_ = enumGetBox(DropdownScrollStrategy_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("scrollStrategy", value_);
        }
        get j() {
            let ret_ = this.i.n("flip");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.i.v("flip", value_);
        }
        get o() {
            let ret_ = this.i.n("distance");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.i.v("distance", value_);
        }
        get k() {
            let ret_ = this.i.n("keepOpenOnOutsideClick");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.i.v("keepOpenOnOutsideClick", value_);
        }
        get n() {
            let ret_ = this.i.n("sameWidth");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.i.v("sameWidth", value_);
        }
        get g() {
            let ret_ = this.i.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.i.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set g(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("size", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.i.r("change", (a) => this.change(this, DropdownItemComponentEventArgs.b(a)));
            }
            else {
                this.i.u("change");
            }
        }
        t() {
            this.nativeElement.hide();
        }
        s() {
            this.nativeElement.clearSelection();
        }
    }
    Dropdown.$t = /*@__PURE__*/ markType(Dropdown, 'Dropdown', BaseElement.$);
    return Dropdown;
})();
